((Drupal, settings, once) => {
  /**
   * Updates the preview iFrame with the new color values.
   * @param colors
   */
  function updatePreview(colors) {
    let style = '';
    Object.entries(colors).forEach((color) => {
      const [key, value] = color;
      style += `--color-${key}: ${value};`;
    });

    // Define the preview iFrame object.
    const iFrameBody = window.frames['altcolor-preview-frame'].document;
    iFrameBody.querySelector('html').setAttribute('style', style);
  }

  /**
   * Event handler for updating the preview.
   * @param event
   */
  function OnAltColorChanged(event) {
    updatePreview(event.detail.colors);
  }

  /**
   * Event handler that executes when the user navigates the iframe. This
   * enables the color overrides to be re-applied when the user is navigating
   * through the website in the iframe.
   */
  function OnIframeLoad() {
    // Trigger the update function of the admin interface. This will in turn
    // fire the 'altcolor-changed' event where we are subscribed to via the
    // behaviors below.
    Drupal.altcolor.update();
  }

  /**
   * Initializes the Alternative Color preview.
   *
   * @type {Drupal~behavior}
   *
   * @prop {Drupal~behaviorAttach} attach
   *   Attaches the behavior for Alternative Color.
   */
  Drupal.behaviors.altcolorPreview = {
    attach: () => {
      // Listen to the altcolor-changed event on the form object. This custom
      // event is defined and triggered in altcolor_admin.js.
      const formElements = once('altcolor', '#altcolor_form');
      formElements.forEach((form) => {
        form.addEventListener('altcolor-changed', OnAltColorChanged);
      });

      // Attach an event listener to the iframe so that it updates the
      // preview when the page loads. This includes navigation to other pages.
      const iframe = once(
        'altcolor-preview-frame',
        'iframe[name="altcolor-preview-frame"]',
      );
      iframe.forEach((form) => {
        form.addEventListener('load', OnIframeLoad);
      });
    },
  };
})(Drupal, drupalSettings, once);
