<?php

namespace Drupal\altcolor\Theme;

use Drupal\Core\Extension\ThemeHandlerInterface;
use Drupal\Core\Routing\RouteMatchInterface;
use Drupal\Core\Session\AccountProxyInterface;
use Drupal\Core\Theme\ThemeNegotiatorInterface;
use Symfony\Component\HttpFoundation\RequestStack;

/**
 * Allows rendering of the front page in a different theme for color previews.
 */
class ColorPreviewThemeNegotiator implements ThemeNegotiatorInterface {

  /**
   * The theme handler.
   *
   * @var \Drupal\Core\Extension\ThemeHandlerInterface
   */
  private $themeHandler;

  /**
   * The request stack.
   *
   * @var \Symfony\Component\HttpFoundation\RequestStack
   */
  protected $requestStack;

  /**
   * The current user.
   *
   * @var \Drupal\Core\Session\AccountProxyInterface
   */
  protected $currentUser;

  /**
   * Constructs a ColorPreviewThemeNegotiator.
   *
   * @param \Drupal\Core\Extension\ThemeHandlerInterface $themeHandler
   *   The theme handler.
   * @param \Symfony\Component\HttpFoundation\RequestStack $requestStack
   *   The request stack.
   * @param \Drupal\Core\Session\AccountProxyInterface $current_user
   *   The current user.
   */
  public function __construct(ThemeHandlerInterface $themeHandler, RequestStack $requestStack, AccountProxyInterface $current_user) {
    $this->themeHandler = $themeHandler;
    $this->requestStack = $requestStack;
    $this->currentUser = $current_user;
  }

  /**
   * Gets the theme.
   *
   * @return string
   *   The theme system name if found, or NULL otherwise.
   */
  protected function getTheme() {
    // @todo Perhaps try to find a better way to manage this. The query
    //   parameter is an easy way to change the theme, but it feels ugly.
    //   Perhaps use a system state instead?
    $altcolor_preview_theme = $this->requestStack->getCurrentRequest()->query->get('altcolor_preview_theme');
    // Check if this is an existing theme and if it is enabled.
    if ($this->themeHandler->themeExists($altcolor_preview_theme)) {
      return $altcolor_preview_theme;
    }
    return NULL;
  }

  /**
   * {@inheritdoc}
   */
  public function applies(RouteMatchInterface $route_match) {
    // Do not allow people to change the appearance of the site by using query
    // parameters. At least do some permission checking.
    if ($this->currentUser->hasPermission('administer themes') && $this->getTheme()) {
      return TRUE;
    }
    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function determineActiveTheme(RouteMatchInterface $route_match) {
    return $this->getTheme();
  }

}
